**************************************************
**  Use this code to replicate household wealth **
**  regressions in Tables 1, 2, A1, A3, A5, A8. **
**	It also creates data for Figures 3 and 5a.  **
**                                              **
**  Note: During execution, this code creates   **
**  files called temp.dta, pwealthresults.dta,  **
**  pwealthsims.dta.  These can be deleted.		**
**  It will also create the data for Figure 3   **
**  in file named fig3data.txt.                 **
**************************************************

cd "/Users/zac/Desktop/ResearchProjects/QJPS/qjps_11022_supp"

clear
set more off


* This code reports the difference in means tests on household wealth
 use cam_household, clear
 ttest pwealth if rural==1, by(british)
 ttest pwealth if rural==0, by(british)

* Set up for regressions

local rural=1
local fig3=0
local fig5=0
local ethnic=""

* turn on local(s) corresponding to indicated table

* Table 1 (also creates data for Figure 3 and placebo tests for Figure 5)
* local controls "dist_capital dist_coast dist_city alt_dem lnlspop malehh "
* local fig3=1
* local fig5=1
 
 
* Table 2 (urban)
* local rural=0

* Table A1
* local controls="dist_capital dist_coast dist_city alt_dem lnlspop malehh "
* local ethnic="ethnic1-ethnic32 "

* Table A3
* local controls="dist_capital dist_coast dist_city alt_dem lnlspop malehh rel_prot rel_cath rel_muslim hh_literate "

* Table A5
* local controls="dist_capital dist_coast dist_city alt_dem lnlspop malehh bamileke_region "

* Table A8
 local controls="dist_capital dist_coast dist_city alt_dem lnlspop malehh hh_outplace "
 local ethnic="ethnic1-ethnic32 "

quietly {

*** Rural

if `rural'==1 {

local zones "zesudansavanna zhighlandforest zcrossriverforest znwcongolianforests zcentafricanmangroves zmtcamforests"

foreach dist in 160 30 20 10 {

if `dist' > 10 {

	local disc="british dist_brit dist_fr "
	
	}
	
	else {
	
		local disc="british "

	}

local ivars="`disc'"+"`controls'"

*estimate regression with corrected locations

	use cam_spatial, clear
	
	qui keep if corrected==1
	qui keep if rural==1
	
	qui save temp, replace
	


	use cam_household, clear

	
	* merge in spatial data
	sort cluster
	qui merge m:1 cluster using temp
	qui drop if _merge==1
	drop _merge
	
	
	* generate religion dummies
	
	qui gen rel_prot=hh_religion==2 if hh_religion!=.
	qui gen rel_cath=hh_religion==1 if hh_religion!=.
	qui gen rel_muslim=hh_religion==3 if hh_religion!=.
		
	* generate ethnicity dummies
	
	qui tab hh_ethnicity, gen(ethnic)
	

version 10.1: qui reg pwealth `ivars' `zones' `ethnic' [pweight=pw] if dist_border<=`dist', cluster(cluster)

mat b=e(b)
mat V=e(V)
local n=e(N)
local r2=e(r2)
local k=colsof(b)
local dfr=e(df_r)	

* output coefficients

noisily di "Corrected locations, dist:",`dist'

local j = 1

foreach v of local ivars {

	local bhat=b[1,`j']
	local se=sqrt(V[`j',`j'])
	local t=`bhat'/`se'
	local p=2*ttail(`dfr',abs(`t'))
	qui sigdig `bhat' 2
	noisily di "`v'", r(value)
	qui sigdig `se' 2
	noisily di "`v'","(",,r(value),,")", "p=",`p'
	
	local j=`j'+1
	}

	
	* output constant
	
	local bhat=b[1,`k']
	local se=sqrt(V[`k',`k'])
	local t=`bhat'/`se'
	local p=2*ttail(`dfr',abs(`t'))
	qui sigdig `bhat' 2
	noisily di "cons", r(value)
	qui sigdig `se' 2
	noisily di "cons","(",,r(value),,")", "p=",`p'
	
	* output other stats
	noisily di "R2 ",`r2'
	noisily di "Obs:",`n'

	noisily di _newline


* Now do imputed locations

* set number of imputations

local m=200

* create a file named pwealthresults.dta that will contain estimates from imputations
clear

qui  set obs `m'

qui gen n=.
qui gen r2=.
qui gen dfr=.
qui gen b_cons=.
qui gen v_cons=.

foreach v of local ivars {

	qui gen b_`v'=.
	qui gen v_`v'=.
	
}
	
qui save pwealthresults, replace

* estimate model on m data sets with imputed locations

forvalues i=1/`m' {

	
	use cam_spatial, clear
	
	* randomly select one observation per cluster
	
	qui keep if imputed==1
	qui gen order=uniform()
	sort cluster order
	qui keep if cluster!=cluster[_n-1]
	drop order
	
	qui save temp, replace
	
	
	*merge spatial data and household data
	
	use cam_household, clear
	
	sort cluster
	qui merge m:1 cluster using temp
	qui drop if _merge==1
	drop _merge

	* generate religion dummies
	
	qui gen rel_prot=hh_religion==2 if hh_religion!=.
	qui gen rel_cath=hh_religion==1 if hh_religion!=.
	qui gen rel_muslim=hh_religion==3 if hh_religion!=.
		
	* generate ethnicity dummies
	
	qui tab hh_ethnicity, gen(ethnic)
	
	* estimate regression

	version 10.1: qui reg pwealth `ivars' `zones' `ethnic' [pweight=pw] if dist_border<=`dist', cluster(cluster)


	* grab regression estimates and save to pwealthresults.dta
	
	mat b=e(b)
	mat V=e(V)
	local n=e(N)
	local r2=e(r2)
	local k=colsof(b)
	local dfr=e(df_r)
	
	use pwealthresults, clear
	
	local j=1
	
	foreach v of local ivars {

	qui replace b_`v'=b[1,`j'] in `i'
	qui replace v_`v'=V[`j',`j'] in `i'
	
	local j=`j'+1
	
	}

	qui replace b_cons=b[1,`k'] in `i'
	qui replace v_cons=V[`k',`k'] in `i'
	qui replace n=`n' in `i'
	qui replace r2=`r2' in `i'
	qui replace dfr=`dfr' in `i'
	
	qui save pwealthresults,replace
	

	* draw parameters from posterior distribution for regression on full sample
	* parameter draws are save to pwealthsims.dta
	
	if `dist'==160&`fig3'==1 {
	
	clear
	
	local sims = 10
	qui set obs `sims'
	
	local l = 1
	capture drop c1-c`k'

	local cnames

	while `l'<=`k' {

		qui gen c`l'=invnorm(uniform()) in 1/`sims'
		local cnames `cnames' "c`l'"
		local l = `l' + 1

	}
	
	matrix B=cholesky(V)
	matrix colnames B=`cnames'
	matrix colnames B=sameeq:

	local bnames : colfullnames b

	local l = 1

	capture drop b1-b`k'

	while `l' <= `k' {

		matrix row=B[`l',1...]
		matrix score b`l'=row
		qui replace b`l'=b`l'+b[1,`l']
		local l = `l' + 1
	
	}

	capture drop c1-c`k'
	
	if `i'==1 {
		
		qui save pwealthsims, replace
		
		}
	
	else {
	
		qui append using pwealthsims
		qui save pwealthsims, replace
	}
	
	

	}

	
	}

* Combine imputation results

use pwealthresults, clear

* calculate min degrees of freedom
qui summ(dfr)
local df_comp=r(min)

* calculate average r2
qui summ(r2)
local r2=r(mean)

* calculate range of obs
qui summ(n)
local nlow=r(min)
local nhi=r(max)

local ivars2="`ivars'"+" cons"

noisily di "Imputed locations, dist:",`dist'

foreach v of local ivars2 {

	
	qui summ b_`v'
	local bhat=r(mean)
	local bvar=r(sd)^2
	qui sum v_`v'
	local wvar=r(mean)
	local se=sqrt(`wvar'+(1+1/`m')*`bvar')
	local t=`bhat'/`se'
	
	local dfm=(`m'-1)/((1+1/`m')*`bvar'/`se'^2)^2
	local dfobs=(`df_comp'+1)/(`df_comp'+3)*`df_comp'*(1-((1+1/`m')*`bvar'/`se'^2))
	local df=(1/`dfm'+1/`dfobs')^(-1)
	local p=2*ttail(`df',abs(`t'))
	
	qui sigdig `bhat' 2
	noisily di "`v'", r(value)
	qui sigdig `se' 2
	noisily di "`v'","(",,r(value),,")", "p=",`p'
	
	}

	noisily di "R2= ",`r2'
	noisily di "Obs:",`nlow',"-",`nhi'
	noisily di _newline
	
** Create data for Figure 3 using full sample and specification from Table 1

if `dist'==160&`fig3'==1 {

* merge in spatial data (corrected locations)

use cam_spatial, clear
	
qui keep if corrected==1
qui keep if rural==1

qui save temp, replace
	
use cam_household, clear

sort cluster

qui merge m:1 cluster using temp
qui drop if _merge==1
qui drop _merge

*  regress data on covariates (minus discontinuity variables) to get residuals

local ivars3="`controls'"+"`zones'"

qui reg pwealth `controls' `zones' [pweight=pw], cluster(cluster)
capture drop pwealth_res
qui predict pwealth_res, resid
qui summ pwealth if e(sample)==1
qui replace pwealth_res=pwealth_res+r(mean)
capture drop avwealth_res
egen avpwealth_res=mean(pwealth_res), by(cluster)

* determine formula for expected dist_capital at each point

sort cluster
qui reg dist_capital british dist_brit dist_fr if cluster!=cluster[_n-1]
mat b=e(b)

* fill matrix of controls with mean values
mat iv=J(`k',1,0)
local i=4
foreach v of local ivars3 {

	qui summ(`v')
	mat iv[`i',1]=r(mean)
	
	local i = `i' +1
	
	}
mat iv[`k',1]=1

* save average wealth residuals
qui keep if cluster!=cluster[_n-1]
qui keep dist_border_dir avpwealth_res
qui save temp, replace


* Now simulate effects

use pwealthsims, clear

qui set matsize 2000
mkmat b1-b`k', matrix(beta)

capture drop dist_border_dir wealth_sim wealth_lo wealth_hi 
capture drop w_hat
qui gen dist_border_dir=.
qui gen wealth_sim=.
qui gen wealth_lo=.
qui gen wealth_hi=.

local i = 1

forvalues x=-100/150 {

	if `x' <0 {

		mat iv[1,1]=1
		mat iv[2,1]=-`x'
		mat iv[3,1]=0
		mat iv[4,1]=b[1,1]-b[1,2]*`x'+b[1,4]
		}
		
		else {
		
		mat iv[1,1]=0
		mat iv[2,1]=0
		mat iv[3,1]=`x'
		mat iv[4,1]=b[1,3]*`x'+b[1,4]
		}
		
	qui replace dist_border_dir=`x' in `i'
	
	mat w_hat=beta*iv
	svmat w_hat, names(w_hat)
	
	qui summ w_hat1
	qui replace wealth_sim=r(mean) in `i'
	
	_pctile w_hat1, p(2.5, 97.5)
	qui replace wealth_lo=r(r1) in `i'
	qui replace wealth_hi=r(r2) in `i'
	
	drop w_hat1
	local i = `i' +1
	
	}

qui keep dist_border_dir wealth_sim wealth_lo wealth_hi
qui keep if dist_border_dir!=.
	
qui append using temp

qui outsheet dist_border_dir wealth_sim wealth_lo wealth_hi avpwealth_res using fig3data.txt, replace comma


}
	
* Display data for placebo tests (Figure 5a)
	
if `dist'==160&`fig5'==1 {

noisily di "Data for Placebo tests, Figure 5a"
noisily di "Border" _column(10) "Estimate" _column(20) "Lower CI" _column(30) "Upper CI"

* loop over 6 placebo borders and real border
forvalues plac=0/6 {

	* create data set to hold estimates

	clear
	qui  set obs `m'
	
	qui gen dfr=.
	qui gen b_cons=.
	qui gen v_cons=.

	foreach v of local ivars {

		qui gen b_`v'=.
		qui gen v_`v'=.
	
	}
	
	qui save pwealthresults, replace


forvalues i=1/`m' {

	use cam_spatial, clear
	
	* randomly select one observation per cluster
	
	qui keep if imputed==1
	qui gen order=uniform()
	sort cluster order
	qui keep if cluster!=cluster[_n-1]
	drop order
	
	qui save temp, replace
	
	*merge spatial data and household data
	
	use cam_household, clear
	
	sort cluster
	qui merge m:1 cluster using temp
	qui drop if _merge==1
	drop _merge
	
	if `plac'!=0 {
	
	qui replace british=british`plac'
	qui replace dist_brit=dist_brit_p`plac'
	qui replace dist_fr=dist_fr_p`plac'
	qui replace dist_border=dist_brit+dist_fr
	}
	
	version 10.1: qui reg pwealth `ivars' `zones' [pweight=pw] if dist_border<=`dist', cluster(cluster)

	mat b=e(b)
	mat V=e(V)
	local n=e(N)
	local r2=e(r2)
	local k=colsof(b)
	local dfr=e(df_r)
	
	use pwealthresults, clear
	
	local j=1
	
	foreach v of local ivars {

	qui replace b_`v'=b[1,`j'] in `i'
	qui replace v_`v'=V[`j',`j'] in `i'
	
	local j=`j'+1
	
	}

	qui replace b_cons=b[1,`k'] in `i'
	qui replace v_cons=V[`k',`k'] in `i'
	qui replace dfr=`dfr' in `i'
	
	qui save pwealthresults,replace
	
	}

	
* Combine results

use pwealthresults, clear

* calculate min degrees of freedom
qui summ(dfr)
local df_comp=r(min)


* get estimate and 95 percent confidence interval around discontinuity

local v="british"

	
	qui summ b_`v'
	local bhat=r(mean)
	local bvar=r(sd)^2
	qui sum v_`v'
	local wvar=r(mean)
	local se=sqrt(`wvar'+(1+1/`m')*`bvar')
	local t=`bhat'/`se'
	
	local dfm=(`m'-1)/((1+1/`m')*`bvar'/`se'^2)^2
	local dfobs=(`df_comp'+1)/(`df_comp'+3)*`df_comp'*(1-((1+1/`m')*`bvar'/`se'^2))
	local df=(1/`dfm'+1/`dfobs')^(-1)
	local p=2*ttail(`df',abs(`t'))
	
	local c=invttail(`df',0.025)
	local upper=`bhat'+`c'*`se'
	local lower=`bhat'-`c'*`se'
	
	qui sigdig `bhat' 3
	local bhat=r(value)
	
	qui sigdig `lower' 3
	local lower=r(value)

	qui sigdig `upper' 3
	local upper=r(value)
	
	
* display

if `plac'==0 {

	local border="True"
	
	}
	
if `plac'==1 {

	local border="30km W"
	
	}
	
if `plac'==2 {

	local border="20km W"
	
	}
	
if `plac'==3 {

	local border="10km W"
	
	}
	
if `plac'==4 {

	local border="10km E"
	
	}
	
if `plac'==5 {

	local border="20km E"
	
	}
	
if `plac'==6 {

	local border="30km E"
	
	}

noisily di "`border'" _column(10) "`bhat'" _column(20) "`lower'" _column(30) "`upper'"

}

noisily di _newline

}

	
}


}

***** Urban

if `rural'==0 {

local zones "zesudansavanna zhighlandforest zcrossriverforest zcentafricanmangroves zmtcamforests"

foreach dist in 150 30 20 10 {

if `dist' > 10 {

	local ivars "british dist_brit dist_fr dist_capital dist_coast dist_road alt_dem malehh"

	}
	
	else {
	
		local ivars "british dist_capital dist_coast dist_road alt_dem malehh"
	}

	
* merge in spatial data

use cam_spatial, clear
qui keep if rural==0
qui save temp, replace
	
use cam_household, clear

sort cluster
qui merge m:1 cluster using temp
qui drop if _merge==1
qui drop _merge

noisily di "Matched locations, dist:",`dist'
noisily version 10.1: reg pwealth `ivars' `zones' [pweight=pw] if dist_border<=`dist', cluster(matchedcitynum)


}
}
}
