**************************************************
**  Use this code to replicate literacy results   **
**  in Table 5                                    **
**                                                **
**  Note: During execution, this code creates     **
**  files called temp.dta and litresults.dta,     **
**  These can be deleted.                     	  **
****************************************************

cd "/Users/zac/Desktop/ResearchProjects/QJPS/qjps_11022_supp"
log using "Tab5.smcl"
clear
set more off


local zones "zesudansavanna zhighlandforest zcrossriverforest znwcongolianforests zcentafricanmangroves zmtcamforests"
local controls "dist_capital dist_coast dist_city alt_dem lnlspop malehh"

foreach dist in 150 30 20 10 {

if `dist' > 10 {

	local disc="british dist_brit dist_fr "
	
	}
	
	else {
	
		local disc="british "

	}

local ivars="`disc'"+"`controls'"

*estimate regression with corrected locations

	use cam_spatial, clear
	
	qui keep if corrected==1
	qui keep if rural==1
	
	qui save temp, replace

	use cam_literacy, clear

	* merge in spatial data
	sort cluster
	qui merge m:1 cluster using temp
	qui drop if _merge==1
	drop _merge

	

version 10.1: qui probit lit_male `ivars' `zones' [pweight=maleweight] if dist_border<=`dist', cluster(cluster)

mat b=e(b)
mat V=e(V)
local n=e(N)
local k=colsof(b)
local dfr=`n'-1-e(df_m)	

* output coefficients

noisily di "Corrected locations, dist:",`dist'

local j = 1

foreach v of local ivars {

	local bhat=b[1,`j']
	local se=sqrt(V[`j',`j'])
	local t=`bhat'/`se'
	local p=2*ttail(`dfr',abs(`t'))
	qui sigdig `bhat' 2
	noisily di "`v'", r(value)
	qui sigdig `se' 2
	noisily di "`v'","(",,r(value),,")", "p=",`p'
	
	local j=`j'+1
	}

	
	* output constant
	
	local bhat=b[1,`k']
	local se=sqrt(V[`k',`k'])
	local t=`bhat'/`se'
	local p=2*ttail(`dfr',abs(`t'))
	qui sigdig `bhat' 2
	noisily di "cons", r(value)
	qui sigdig `se' 2
	noisily di "cons","(",,r(value),,")", "p=",`p'
	
	* output other stats
	noisily di "Obs:",`n'
	noisily di _newline

* do estimates with imputed locations

clear

* set number of imputations
local m=200


* create data set to hold estimates

qui  set obs `m'
qui gen n=.
qui gen dfr=.
qui gen b_cons=.
qui gen v_cons=.

foreach v of local ivars {

	qui gen b_`v'=.
	qui gen v_`v'=.
	
}
	
qui save litresults, replace

* loop over m imputed data sets

forvalues i=1/`m' {
	
	use cam_spatial, clear
	
	* randomly select one imputed location
	
	qui keep if imputed==1
	qui gen order=uniform()
	sort cluster order
	qui keep if cluster!=cluster[_n-1]
	drop order
	
	qui save temp, replace
	
	
	*merge spatial data and literacy data
	
	use cam_literacy, clear
	
	sort cluster
	qui merge m:1 cluster using temp
	qui drop if _merge==1
	drop _merge

	
	version 10.1: qui probit lit_male `ivars' `zones' [pweight=maleweight] if dist_border<=`dist', cluster(cluster)
	
	mat b=e(b)
	mat V=e(V)
	local n=e(N)
	local k=colsof(b)
	local dfr=`n'-1-e(df_m)
	
	use litresults, clear
	
	local j=1
	
	foreach v of local ivars {

	qui replace b_`v'=b[1,`j'] in `i'
	qui replace v_`v'=V[`j',`j'] in `i'
	
	local j=`j'+1
	
	}

	qui replace b_cons=b[1,`k'] in `i'
	qui replace v_cons=V[`k',`k'] in `i'
	qui replace n=`n' in `i'
	qui replace dfr=`dfr' in `i'
	
	qui save litresults,replace
	

	
	}


* Combine results

use litresults, clear

* calculate min degrees of freedom
qui summ(dfr)
local df_comp=r(min)


* calculate range of obs
qui summ(n)
local nlow=r(min)
local nhi=r(max)

local ivars2="`ivars'"+" cons"

noisily di "Imputed locations, dist:",`dist'

foreach v of local ivars2 {
	
	qui summ b_`v'
	local bhat=r(mean)
	local bvar=r(sd)^2
	qui sum v_`v'
	local wvar=r(mean)
	local se=sqrt(`wvar'+(1+1/`m')*`bvar')
	local t=`bhat'/`se'
	
	local dfm=(`m'-1)/((1+1/`m')*`bvar'/`se'^2)^2
	local dfobs=(`df_comp'+1)/(`df_comp'+3)*`df_comp'*(1-((1+1/`m')*`bvar'/`se'^2))
	local df=(1/`dfm'+1/`dfobs')^(-1)
	local p=2*ttail(`df',abs(`t'))
	
	qui sigdig `bhat' 2
	noisily di "`v'", r(value)
	qui sigdig `se' 2
	noisily di "`v'","(",,r(value),,")", "p=",`p'
	
	}

	noisily di "Obs:",`nlow',"-",`nhi'
	noisily di _newline


}





