
*******************************************
**  This code conducts the analysis of   **
**  neighboring pairs of rural clusters. **  
**  There are two parts to the analysis. **
**  The first uses the household-level   **
**  To compare wealth and water in the   **
**  cross-border pairs.  The second part **
**  part uses data on differences within **
**  pairs to compare cross-border with   **
**  non-cross border pairs (using unique **
**  subsets.                             **
*******************************************

cd "/Users/zac/Desktop/ResearchProjects/QJPS/qjps_11022_supp"

* Analyze differences between clusters in cross border pairs

use cam_household, clear

* fill matrix with identifiers of cross-border cluster pairs

matrix input P = (372,24\ 19,26	\346,26	\325,26	\301,26	\146,26\19,152\346,152\146,152\288,152\133,347\407,347\151,353\386,353\407,353\109,353\464,403\372,403\288,453\247,465\406,465)	


* create some variables to hold results

qui gen brit_higher=. in 1/21
qui gen fr_higher=. in 1/21
qui gen sig10per=. in 1/21

* ttests of average wealth in 21 cross-border pairs

forvalues i=1/21 {

	ttest pwealth if cluster==P[`i',1]|cluster==P[`i',2],by(british) unequal
	qui replace brit_higher=r(t)<0 in `i'
	qui replace fr_higher=r(t)>0 in `i'
	qui replace sig10per=r(p)<0.1 in `i'
}

* display number of pairs in which British (French) cluster has higher average wealth
* and whether the difference in means is significant

tab brit_higher sig10per
tab fr_higher sig10per

* clear variables for water test

qui replace brit_higher=. in 1/21
qui replace fr_higher=. in 1/21
qui replace sig10per=. in 1/21

* proportions test of access to piped water in cross-border cluster


forvalues i=1/21 {

	prtest pipedwater if cluster==P[`i',1]|cluster==P[`i',2],by(british) 
	qui replace brit_higher=r(z)<0 if r(z)!=. in `i'
	qui replace fr_higher=r(z)>0 if r(z)!=. in `i'
	qui replace sig10per=2*(1-normal(abs(r(z))))<0.1 in `i'
	qui replace sig10per=0 if r(z)==. in `i'
}

* display number of pairs in which British (French) cluster has higher average wealth
* and whether the difference in means is significant

tab brit_higher sig10per
tab fr_higher sig10per


**** Unique pairs analysis
**** Note: results are saved to a file named ruralneighborcomparisons.dta

set more off

clear

* create variables to hold results

qui gen ncross=.
qui gen nnoncross=.

qui gen diff_pwealth=.
qui gen p_diff_pwealth=.
qui gen se_diff_pwealth=.

qui gen diff_piped=.
qui gen p_diff_piped=.
qui gen se_diff_piped=.


forvalues k=1/8 {
	qui gen p`k'=.
	
	}
	
* create file to hold results

save ruralneighborcomparisons, replace

* Loop over a large number of randomly selected data sets
* We will later delete data sets that use the same set of cross-border pairs

forvalues j = 1/10000 {

qui {
clear

* this data set contains data on wealth and water differences in
* cluster pairs that are within 30km of each other

use cam_neighbors

* the following code randomly selects a subset of unique pairs

capture drop order
gen order=uniform()
gen notcrossborder=1-crossborder
sort notcrossborder order

capture drop insample
gen insample=0

qui summ cluster1
local n=r(N)

local i=1

while `i'<=`n' {
	
	qui replace insample=1 in `i'
	qui drop if insample==0&(cluster1==cluster1[`i']|cluster2==cluster2[`i'])
	
	local i=`i'+1
	qui summ cluster1
	local n=r(N)
	
	}


* compare wealth difference in cross border pairs with non-cross border pairs

ttest pwealthdiff, by(crossborder) unequal

* save test results

local a=r(mu_2)-r(mu_1)
local b= r(p)
local b2=r(se)
local c =r(N_2)
local d= r(N_1)

* compare piped water difference in cross border pairs with non-cross border pairs

ttest pipeddiff, by(crossborder) unequal

* save test results
local g=r(mu_2)-r(mu_1)
local h= r(p)
local h2=r(se)


* the following code determines, for each imputed data set,
* which French cluster was partnered with each of the 8
* British clusters that are present in cross-border pairs
* We will later drop tests that duplicate these partners

qui summ cluster1 if cluster2==24
local p1=0
if r(N)==1 {

	local p1=r(mean)
	}

qui summ cluster1 if cluster2==26
local p2=0
if r(N)==1 {

	local p2=r(mean)
	}

qui summ cluster1 if cluster2==152
local p3=0
if r(N)==1 {

	local p3=r(mean)
	}

qui summ cluster1 if cluster2==347
local p4=0
if r(N)==1 {

	local p4=r(mean)
	}

qui summ cluster1 if cluster2==353
local p5=0
if r(N)==1 {

	local p5=r(mean)
	}

qui summ cluster1 if cluster2==403
local p6=0
if r(N)==1 {

	local p6=r(mean)
	}

qui summ cluster1 if cluster2==453
local p7=0
if r(N)==1 {

	local p7=r(mean)
	}

qui summ cluster1 if cluster2==465
local p8=0
if r(N)==1 {

	local p8=r(mean)
	}

* put test results into data set that is collecting results

use ruralneighborcomparisons, clear

set obs 10000

qui replace diff_pwealth=`a' in `j'
qui replace p_diff_pwealth=`b' in `j'
qui replace se_diff_pwealth=`b2' in `j'
qui replace ncross=`c' in `j'
qui replace nnoncross=`d' in `j'
qui replace diff_piped=`g' in `j'
qui replace p_diff_piped=`h' in `j'
qui replace se_diff_piped=`h2' in `j'

forvalues k=1/8 {
	qui replace p`k'=`p`k'' in `j'
	
	}


save ruralneighborcomparisons, replace

}
}


* drop samples that duplicate the set of cross-border pairs
* this should leave 476 tests
duplicates drop p1-p8, force
save ruralneighborcomparisons, replace

* display results of wealth comparisons

use ruralneighborcomparisons,clear

qui {

* summary statistics of delta=diff_pwealth
noisily di "Wealth comparisons"

noisily summ diff_pwealth
local mu=r(mean)

* calculate standard error of delta across pwealth tests

* calculate within-variance

qui gen se_diff_pwealth2=se_diff_pwealth^2
qui summ se_diff_pwealth2
local u=r(mean)

* calculate between variance

local b=0

forvalues i=1/476 {

	local b=`b'+(diff_pwealth[`i']-`mu')^2
	}
local b =`b'/475

local v=`u'+(1+1/476)*`b'
local t=`mu'/sqrt(`v')

local df=475*(1+476*`u'/477*`b')^2
local p=2*ttail(`df',abs(`t'))

noi di "Mean of delta=" `mu'
noi di "Standard error of delta=",sqrt(`v')
noi di "p-value=",`p'
noi di _newline
* display results of piped water comparisons

* summary statistics of delta=diff_piped
noi di "Piped water comparisons"

noi summ diff_piped
local mu=r(mean)

* calculate standard error of delta across piped water tests

* calculate within-variance

qui gen se_diff_piped2=se_diff_piped^2
qui summ se_diff_piped2
local u=r(mean)

* calculate between variance

local b=0

forvalues i=1/476 {

	local b=`b'+(diff_piped[`i']-`mu')^2
	}
local b =`b'/475

local v=`u'+(1+1/476)*`b'
local t=`mu'/sqrt(`v')

local df=475*(1+476*`u'/477*`b')^2
local p=2*ttail(`df',abs(`t'))

noi di "Mean of delta=" `mu'
noi di "Standard error of delta=",sqrt(`v')
noi di "p-value=",`p'
}
