**************************************************
**  Use this code to replicate household wealth   **
**  regresssions in Tables 3, 4, A2, A4, A6, A9.  **
**  It also creates data for Figures 4 and 5.	  **
**                                                **
**  Note: During execution, this code creates     **
**  files called temp.dta, pipedwaterresults.dta, **
**  pipedwatersims.dta.  These can be deleted.	  **
**  It will also create the data for Figure 4     **
**  in file named fig4data.txt                    **
****************************************************

clear
set more off

cd "/afs/ir/users/z/a/zacp/private/QJPS/LeeSchultz"

*This code reports the overall comparison across households
 use cam_household, clear

 tab pipedwater british if rural==1, col chi
 tab pipedwater british if rural==0, col chi

* Set up for regressions 
 
local rural=1
local fig4=0
local fig5=0

* turn on local(s) corresponding to indicated table

*Table 3 (also creates data for Figures 4 and 5b)
 local controls "avpwealth dist_capital alt_dem lnlspop "
 local fig4=1
 local fig5=1
 
* Table 4 (urban)
* local rural=0

* Table A2
* local controls "dist_capital alt_dem lnlspop "

* Table A4
* local controls "avpwealth dist_capital alt_dem lnlspop oppshare "

* Table A6
* local controls "avpwealth dist_capital alt_dem lnlspop bamileke_region "

* Table A9
* local controls "avpwealth dist_capital alt_dem lnlspop dist_helvetas "

quietly {
**** Rural

if `rural'==1 {



clear
clear matrix

local m=200

foreach dist in 160 30 20 10 {

if `dist' > 10 {

	local disc="british dist_brit dist_fr "
	
	}
	
	else {
	
	local disc="british "

	}

	
local ivars="`disc'"+"`controls'"

	
*get corrected locations

use cam_spatial, clear
qui keep if rural==1
qui keep if corrected==1
save temp, replace

* reduce household data to cluster data and merge with spatial data
use cam_household, clear

sort cluster
keep if cluster!=cluster[_n-1]

qui merge m:1 cluster using temp
qui drop if _merge==1
drop _merge

*estimate GLM 

 glm npiped `ivars'  if dist_border<=`dist', link(logit) family(binomial nhouse) robust

mat b=e(b)
mat V=e(V)
local n=e(N)
local dfr=`n'-1-e(df_m)	
local k_orig=e(k)
local L_orig=e(ll)

* output coefficients

noisily di "Corrected locations, dist:",`dist'

local j = 1

foreach v of local ivars {

	local bhat=b[1,`j']
	local se=sqrt(V[`j',`j'])
	local t=`bhat'/`se'
	local p=2*ttail(`dfr',abs(`t'))
	qui sigdig `bhat' 2
	noisily di "`v'", r(value)
	qui sigdig `se' 2
	noisily di "`v'","(",,r(value),,")","p=",`p'
	
	local j=`j'+1
	}

	
	* output constant
	
	local bhat=b[1,`j']
	local se=sqrt(V[`j',`j'])
	local t=`bhat'/`se'
	local p=2*ttail(`dfr',abs(`t'))
	qui sigdig `bhat' 2
	noisily di "cons", r(value)
	qui sigdig `se' 2
	noisily di "cons","(",,r(value),,")","p=",`p'
	
local j = `j'+1
	
	* output other stats
	noisily di "N="+`n'

	noisily di _newline
	
*** estimate model using imputated locations
	
* create file to hold estimates
clear
qui set obs `m'

qui gen n=.
qui gen dfr=.

foreach v of local ivars {

	qui gen b_`v'=.
	qui gen v_`v'=.
}


qui gen b_cons=.
qui gen v_cons=.

qui save pipedwaterresults, replace

* loop over m imputated data sets

forvalues i=1/`m' {

	* randomly select one imputed location for each cluster
	use cam_spatial, clear
	keep if imputed==1
	qui gen order=uniform()
	sort cluster order
	qui keep if cluster!=cluster[_n-1]
	drop order
	
	qui save temp, replace
	
	* reduce household data to cluster data and merge with spatial data
	use cam_household, clear	
	sort cluster
	qui keep if cluster!=cluster[_n-1]
	
	qui merge m:1 cluster using temp
	qui drop if _merge==1
	drop _merge

	* estimate GLM
	
	glm npiped `ivars'  if dist_border<=`dist', link(logit) family(binomial nhouse) robust

	mat b=e(b)
	mat V=e(V)
	local n=e(N)
	local k=colsof(b)
	local dfr=`n'-1-e(df_m)
	
	use pipedwaterresults, clear
	
	local j=1
	
	foreach v of local ivars {

	qui replace b_`v'=b[1,`j'] in `i'
	qui replace v_`v'=V[`j',`j'] in `i'
	
	local j=`j'+1
	
	}

	qui replace b_cons=b[1,`j'] in `i'
	qui replace v_cons=V[`j',`j'] in `i'
	
	qui replace n=`n' in `i'
	qui replace dfr=`dfr' in `i'
	
	qui save pipedwaterresults,replace
	
	if 1==1 {
	
	* draw parameters from posterior distribution for Figure 4
	
	if `dist'==160&`fig4'==1 {
	
	clear
	
	local sims = 10
	qui set obs `sims'
	
	local l = 1
	capture drop c1-c`k'

	local cnames

	while `l'<=`k' {

		qui gen c`l'=invnorm(uniform()) in 1/`sims'
		local cnames `cnames' "c`l'"
		local l = `l' + 1

	}
	
	matrix B=cholesky(V)
	matrix colnames B=`cnames'
	matrix colnames B=sameeq:

	local bnames : colfullnames b

	local l = 1

	capture drop b1-b`k'

	while `l' <= `k' {

		matrix row=B[`l',1...]
		matrix score b`l'=row
		qui replace b`l'=b`l'+b[1,`l']
		local l = `l' + 1
	
	}

	capture drop c1-c`k'
	
	if `i'==1 {
		
		qui save pipedwatersims, replace
		
		}
	
	else {
	
		qui append using pipedwatersims
		qui save pipedwatersims, replace
	}
	}
	
	}
	
	
	}

	
* Combine results from imputations

use pipedwaterresults, clear

noisily di "Imputed locations, dist:",`dist'

qui summ(n)
if r(N)!=`m' {
	noisily di "Warning: Only",r(N),"models converged"
	
	}

* calculate min degrees of freedom
qui summ(dfr)
local df_comp=r(min)

* calculate range of obs
qui summ(n)
local nlow=r(min)
local nhi=r(max)

local ivars2="`ivars'"+" cons"

foreach v of local ivars2 {

	qui summ b_`v'
	local bhat=r(mean)
	local bvar=r(sd)^2
	qui sum v_`v'
	local wvar=r(mean)
	local se=sqrt(`wvar'+(1+1/`m')*`bvar')
	local t=`bhat'/`se'
	
	local dfm=(`m'-1)/((1+1/`m')*`bvar'/`se'^2)^2
	local dfobs=(`df_comp'+1)/(`df_comp'+3)*`df_comp'*(1-((1+1/`m')*`bvar'/`se'^2))
	local df=(1/`dfm'+1/`dfobs')^(-1)
	local p=2*ttail(`df',abs(`t'))
	
	qui sigdig `bhat' 2
	noisily di "`v'", r(value)
	qui sigdig `se' 2
	noisily di "`v'","(",,r(value),,")","p=",`p'
	
	}

	noisily di "Obs:",`nlow',"-",`nhi'
	noisily di _newline

** Create data for Figure 4 
		
if `dist'==160&`fig4'==1 {

*get corrected locations

use cam_spatial, clear
qui keep if rural==1
qui keep if corrected==1
save temp, replace

* reduce household data to cluster data and merge with spatial data
use cam_household, clear

sort cluster
keep if cluster!=cluster[_n-1]

qui merge m:1 cluster using temp
qui drop if _merge==1
drop _merge

* determine formula for expected dist_capital at each point

qui reg dist_capital british dist_brit dist_fr if dist_border<=150
mat bcap=e(b)

* fill matrix of controls with mean values
mat iv=J(`k',1,0)
local i=4
foreach v of local controls {

	qui summ(`v')
	mat iv[`i',1]=r(mean)
	
	local i = `i' +1
	
	}
mat iv[`k',1]=1

* save temp file with observed values
keep dist_border_dir avpiped
save temp, replace

* generate predicted values

use pipedwatersims, clear

set matsize 2000
mkmat b1-b`k', matrix(beta)

capture drop dist_border_dir water_sim water_lo water_hi 
capture drop w_hat
gen dist_border_dir=.
gen water_sim=.
gen water_lo=.
gen water_hi=.

local i = 1

forvalues x=-100/150 {

	if `x' <0 {

		mat iv[1,1]=1
		mat iv[2,1]=-`x'
		mat iv[3,1]=0
		mat iv[4,1]=bcap[1,1]-bcap[1,2]*`x'+bcap[1,4]
		}
		
		else {
		
		mat iv[1,1]=0
		mat iv[2,1]=0
		mat iv[3,1]=`x'
		mat iv[4,1]=bcap[1,3]*`x'+bcap[1,4]
		}
		
	qui replace dist_border_dir=`x' in `i'
	
	mat w_hat=beta*iv
	svmat w_hat, names(w_hat)
	
	qui replace w_hat1=exp(w_hat1)/(1+exp(w_hat1))
	
	qui summ w_hat1
	qui replace water_sim=r(mean) in `i'
	
	_pctile w_hat1, p(2.5, 97.5)
	qui replace water_lo=r(r1) in `i'
	qui replace water_hi=r(r2) in `i'
	
	drop w_hat1
	local i = `i' +1
	
	}

keep dist_border_dir water_sim water_lo water_hi 
drop if dist_border_dir!=.

append using temp

outsheet dist_border_dir water_sim water_lo water_hi avpiped using fig4data.txt, replace comma


}	

* Display data for placebo tests (Figure 5b)
	
if `dist'==160&`fig5'==1 {

noisily di "Data for Placebo tests, Figure 5b"
noisily di "Border" _column(10) "Estimate" _column(20) "Lower CI" _column(30) "Upper CI"

* loop over 6 placebo borders and real border
forvalues plac=0/6 {

	* create data set to hold estimates

	clear
	qui  set obs `m'
	
	qui gen dfr=.
	qui gen b_cons=.
	qui gen v_cons=.

	foreach v of local ivars {

		qui gen b_`v'=.
		qui gen v_`v'=.
	
	}
	
	qui save pipedwaterresults, replace


forvalues i=1/`m' {

	use cam_spatial, clear
	
	* randomly select one observation per cluster
	
	qui keep if imputed==1
	qui gen order=uniform()
	sort cluster order
	qui keep if cluster!=cluster[_n-1]
	drop order
	
	qui save temp, replace
	
	*merge spatial data and household data
	
	use cam_household, clear
	sort cluster
	qui keep if cluster!=cluster[_n-1]

	qui merge m:1 cluster using temp
	qui drop if _merge==1
	drop _merge
	
	if `plac'!=0 {
	
	qui replace british=british`plac'
	qui replace dist_brit=dist_brit_p`plac'
	qui replace dist_fr=dist_fr_p`plac'
	qui replace dist_border=dist_brit+dist_fr
	}
	
	qui glm npiped `ivars'  if dist_border<=`dist', link(logit) family(binomial nhouse) robust

	mat b=e(b)
	mat V=e(V)
	local n=e(N)
	local k=colsof(b)
	local dfr=`n'-1-e(df_m)
	
	use pipedwaterresults, clear
	
	local j=1
	
	foreach v of local ivars {

	qui replace b_`v'=b[1,`j'] in `i'
	qui replace v_`v'=V[`j',`j'] in `i'
	
	local j=`j'+1
	
	}

	qui replace b_cons=b[1,`j'] in `i'
	qui replace v_cons=V[`j',`j'] in `i'
	
	qui replace dfr=`dfr' in `i'
	
	qui save pipedwaterresults,replace
	
	}

	
* Combine results

use pipedwaterresults, clear


* calculate min degrees of freedom
qui summ(dfr)
local df_comp=r(min)


local v="british"

	qui summ b_`v'
	local bhat=r(mean)
	local bvar=r(sd)^2
	qui sum v_`v'
	local wvar=r(mean)
	local se=sqrt(`wvar'+(1+1/`m')*`bvar')
	local t=`bhat'/`se'
	
	local dfm=(`m'-1)/((1+1/`m')*`bvar'/`se'^2)^2
	local dfobs=(`df_comp'+1)/(`df_comp'+3)*`df_comp'*(1-((1+1/`m')*`bvar'/`se'^2))
	local df=(1/`dfm'+1/`dfobs')^(-1)
	local p=2*ttail(`df',abs(`t'))
	
	local c=invttail(`df',0.025)
	local upper=`bhat'+`c'*`se'
	local lower=`bhat'-`c'*`se'
	
	qui sigdig `bhat' 3
	local bhat=r(value)
	
	qui sigdig `lower' 3
	local lower=r(value)

	qui sigdig `upper' 3
	local upper=r(value)
	
	
* display

if `plac'==0 {

	local border="True"
	
	}
	
if `plac'==1 {

	local border="30km W"
	
	}
	
if `plac'==2 {

	local border="20km W"
	
	}
	
if `plac'==3 {

	local border="10km W"
	
	}
	
if `plac'==4 {

	local border="10km E"
	
	}
	
if `plac'==5 {

	local border="20km E"
	
	}
	
if `plac'==6 {

	local border="30km E"
	
	}

noisily di "`border'" _column(10) "`bhat'" _column(20) "`lower'" _column(30) "`upper'"

}

noisily di _newline
}


}

}


* Urban

if `rural'==0 {

foreach dist in 150 30 20 10{

if `dist' > 10 {

	local ivars "british dist_brit dist_fr avpwealth dist_capital alt_dem "
	
	}
	
	else {
	
		local ivars "british avpwealth dist_capital alt_dem "
	}
	
*get corrected locations

use cam_spatial, clear
qui keep if rural==0
qui keep if corrected==1
save temp, replace

* reduce household data to cluster data and merge with spatial data
use cam_household, clear

sort cluster
keep if cluster!=cluster[_n-1]

qui merge m:1 cluster using temp
qui drop if _merge==1
drop _merge

noisily di "Matched locations, dist:",`dist'
glm npiped `ivars' if dist_border <=`dist', family(binomial nhouse) link(logit) robust

mat b=e(b)
mat V=e(V)
local n=e(N)
local dfr=e(df)	


local j = 1

foreach v of local ivars {

	local bhat=b[1,`j']
	local se=sqrt(V[`j',`j'])
	local t=`bhat'/`se'
	local p=2*ttail(`dfr',abs(`t'))
	
	qui sigdig `bhat' 2
	noisily di "`v'", r(value)
	qui sigdig `se' 2
	noisily di "`v'","(",,r(value),,")","p=",`p'
	
	local j=`j'+1
	}

	
	* output constant
	
	local bhat=b[1,`j']
	local se=sqrt(V[`j',`j'])
	local t=`bhat'/`se'
	local p=2*ttail(`dfr',abs(`t'))
	qui sigdig `bhat' 2
	noisily di "cons", r(value)
	qui sigdig `se' 2
	noisily di "cons","(",,r(value),,")","p=",`p'

	
	* output other stats
	noisily di "N="+`n'


}
	
}

}
